@@ -1,6 +1,9 @@
 # Messages
 .MSG_NOT_AVAILABLE = "Sorry. This series is not yet available."
 .MSG_NOT_FOUND = "Sorry. Series was not found."
-.MSG_PARAMETER_NOT_VALID = "Paramenter is not valid. Check the help files for a list of possible vaues."
+.MSG_PARAMETER_NOT_VALID = "Parameter is not valid. Check the help files for a list of possible vaues."
 .MSG_LANG_NOT_AVAILABLE = "Language option is not avaiable. BETS reports are only available in english or portuguese."
 .MSG_OUT_NOT_AVAILABLE = "Output option is not avaiable. BETS charts can only be saved as .png ou .pdf"
+
+# Wanining
+.WARN_SOFT = "Don't worry, this is not a critical problem. We are working on a solution."
\ No newline at end of file
